@@ -2,9 +2,18 @@ from abc import ABC, abstractmethod
 from typing import Any
 from pydantic import BaseModel, Field
 import pandas as pd
+from enum import Enum
+
+
+class DbType(str, Enum):
+    """数据库类型"""
+
+    MySql = "mysql"
+    ClickHouse = "clickhouse"
 
 
 class DbConfig(BaseModel):
+    type: DbType = Field(title="数据库类型", default=DbType.MySql)
     host: str = Field(title="数据库IP地址", default=None)
     port: int = Field(title="数据库端口", default=None)
     user: str = Field(title="数据库连接账号", default=None)
@@ -29,7 +38,7 @@ class BaseJdbcTemplate(ABC):
         """查询返回pandas的DataFrame"""
 
     @abstractmethod
-    def insert_df(self, table_name: str, record_df:pd.DataFrame):
+    def insert_df(self, table_name: str, record_df: pd.DataFrame):
         """执行数据插入"""
 
     @abstractmethod
