@@ -2,7 +2,7 @@
 # Copyright (c) Microsoft. All rights reserved.
 # Licensed under the MIT license. See LICENSE file in the project.
 #
-"""Datashaper constants."""
+"""constants."""
 
 DEFAULT_INPUT_NAME = "source"
 DEFAULT_OUTPUT_NAME = "result"
