@@ -10,7 +10,7 @@ def run_data_shaper(work_flow_schema_path: str) -> DataFrame:
     if not os.path.exists(work_flow_schema_path):
         raise ValueError(work_flow_schema_path + '不存在')
 
-    with open(work_flow_schema_path, 'r') as json_file:
+    with open(work_flow_schema_path, 'r', encoding='utf-8') as json_file:
         workflow_schema = json.load(json_file)
 
     work_flow = Workflow(schema=workflow_schema)
