@@ -1,4 +1,4 @@
-"""Datashaper Workflow module."""
+"""Workflow module."""
 
 from .csv import load_csv_table
 from .json import load_json_table
