@@ -1,4 +1,4 @@
-"""The tablestore module contains the table store classes used by the datashaper."""
+"""The tablestore module contains the table store classes ."""
 
 from .disk_cache_table_store import DiskCacheTableStore
 from .in_memory_table_store import InMemoryTableStore
