@@ -2,7 +2,7 @@
 # Copyright (c) Microsoft. All rights reserved.
 # Licensed under the MIT license. See LICENSE file in the project.
 #
-"""The tablestore module contains the table store classes used by the datashaper."""
+"""The tablestore module contains the table store classes ."""
 
 from dataclasses import dataclass
 
