@@ -1,4 +1,4 @@
-"""Datashaper Function Decorators."""
+""" Function Decorators."""
 
 from .apply_decorators import apply_decorators
 from .inputs import inputs
