@@ -28,15 +28,12 @@ def load_verbs(module: ModuleType) -> None:
             module_spec = importlib.util.spec_from_file_location(
                 module_name, str(full_path)
             )
-            # print('加载文件verb:', full_path)
             if module_spec is not None:
                 module_to_load = f"{module_spec.name}.{sub_module}"
                 importlib.import_module(module_to_load)
-                logger.info("Found module: %s", module_to_load)
-                # print('加载模块verb:', module_to_load)
+                logger.info("加载模块: %s", module_to_load)
         else:
             full_path = Path(module_path) / sub_module
-            # print('加载文件verb:', full_path)
             sub_module_name = f"{module_name}.{sub_module}"
             sub_module_rec = importlib.import_module(sub_module_name)
             load_verbs(sub_module_rec)
