@@ -1,4 +1,4 @@
-"""Datashaper Engine types."""
+""" Engine types."""
 
 from collections.abc import Callable
 from dataclasses import dataclass
