@@ -1,4 +1,4 @@
-"""Datashaper Workflow module."""
+"""Workflow module."""
 
 from .callbacks import (
     MemoryProfilingWorkflowCallbacks,
