@@ -121,7 +121,7 @@ class Workflow(Generic[Context]):
         # Perform JSON-schema validation
         # TODO(Chris): the current schema definition does not work in Python
         if validate and schema_path is not None:
-            with Path(schema_path).open() as schema_file:
+            with Path(schema_path).open(encoding='utf-8') as schema_file:
                 schema_json = json.load(schema_file)
                 validate_schema(schema, schema_json)
 
@@ -133,7 +133,7 @@ class Workflow(Generic[Context]):
                     table.convert_dtypes(dtype_backend=pandas_dtype_backend.value),
                 )
         else:
-            print('workflow:使用空DataFrame作为初始输入')
+            log.warning('workflow:使用空DataFrame作为初始输入')
             self.add_table(
                 DEFAULT_INPUT_NAME,
                 pd.DataFrame(),
